@@ -3,16 +3,16 @@ package debug
 import (
 	"os"
 
-	"github.com/git-town/git-town/v12/src/cli/dialog"
-	"github.com/git-town/git-town/v12/src/cli/dialog/components"
-	"github.com/git-town/git-town/v12/src/config/configdomain"
+	"github.com/git-town/git-town/v13/src/cli/dialog"
+	"github.com/git-town/git-town/v13/src/cli/dialog/components"
+	"github.com/git-town/git-town/v13/src/config/configdomain"
 	"github.com/spf13/cobra"
 )
 
 func enterGiteaToken() *cobra.Command {
 	return &cobra.Command{
 		Use: "gitea-token",
-		RunE: func(cmd *cobra.Command, args []string) error {
+		RunE: func(_ *cobra.Command, _ []string) error {
 			dialogInputs := components.LoadTestInputs(os.Environ())
 			_, _, err := dialog.GiteaToken(configdomain.GiteaToken(""), dialogInputs.Next())
 			return err
