@@ -3,16 +3,16 @@ package debug
 import (
 	"os"
 
-	"github.com/git-town/git-town/v12/src/cli/dialog"
-	"github.com/git-town/git-town/v12/src/cli/dialog/components"
-	"github.com/git-town/git-town/v12/src/git/gitdomain"
+	"github.com/git-town/git-town/v13/src/cli/dialog"
+	"github.com/git-town/git-town/v13/src/cli/dialog/components"
+	"github.com/git-town/git-town/v13/src/git/gitdomain"
 	"github.com/spf13/cobra"
 )
 
 func selectCommitAuthorCmd() *cobra.Command {
 	return &cobra.Command{
 		Use: "select-commit-author",
-		RunE: func(cmd *cobra.Command, args []string) error {
+		RunE: func(_ *cobra.Command, _ []string) error {
 			branch := gitdomain.NewLocalBranchName("feature-branch")
 			authors := []string{"Jean-Luc Picard <captain@enterprise.com>", "William Riker <numberone@enterprise.com>"}
 			dialogTestInputs := components.LoadTestInputs(os.Environ())
