@@ -4,18 +4,18 @@ import (
 	"fmt"
 	"os"
 
-	"github.com/git-town/git-town/v12/src/cli/dialog/components"
-	"github.com/git-town/git-town/v12/src/cli/flags"
-	"github.com/git-town/git-town/v12/src/cmd/cmdhelpers"
-	"github.com/git-town/git-town/v12/src/config/configdomain"
-	"github.com/git-town/git-town/v12/src/config/gitconfig"
-	"github.com/git-town/git-town/v12/src/execute"
-	"github.com/git-town/git-town/v12/src/git/gitdomain"
-	"github.com/git-town/git-town/v12/src/sync"
-	"github.com/git-town/git-town/v12/src/undo/undoconfig"
-	fullInterpreter "github.com/git-town/git-town/v12/src/vm/interpreter/full"
-	"github.com/git-town/git-town/v12/src/vm/program"
-	"github.com/git-town/git-town/v12/src/vm/runstate"
+	"github.com/git-town/git-town/v13/src/cli/dialog/components"
+	"github.com/git-town/git-town/v13/src/cli/flags"
+	"github.com/git-town/git-town/v13/src/cmd/cmdhelpers"
+	"github.com/git-town/git-town/v13/src/config/configdomain"
+	"github.com/git-town/git-town/v13/src/config/gitconfig"
+	"github.com/git-town/git-town/v13/src/execute"
+	"github.com/git-town/git-town/v13/src/git/gitdomain"
+	"github.com/git-town/git-town/v13/src/sync"
+	"github.com/git-town/git-town/v13/src/undo/undoconfig"
+	fullInterpreter "github.com/git-town/git-town/v13/src/vm/interpreter/full"
+	"github.com/git-town/git-town/v13/src/vm/program"
+	"github.com/git-town/git-town/v13/src/vm/runstate"
 	"github.com/spf13/cobra"
 )
 
@@ -46,7 +46,7 @@ func syncCmd() *cobra.Command {
 		Args:    cobra.NoArgs,
 		Short:   syncDesc,
 		Long:    cmdhelpers.Long(syncDesc, fmt.Sprintf(syncHelp, gitconfig.KeySyncUpstream)),
-		RunE: func(cmd *cobra.Command, args []string) error {
+		RunE: func(cmd *cobra.Command, _ []string) error {
 			return executeSync(readAllFlag(cmd), readDryRunFlag(cmd), readVerboseFlag(cmd))
 		},
 	}
