@@ -4,19 +4,18 @@ import (
 	"errors"
 	"os"
 
-	"github.com/git-town/git-town/v12/src/config"
-	"github.com/git-town/git-town/v12/src/config/configdomain"
-	"github.com/git-town/git-town/v12/src/config/configfile"
-	"github.com/git-town/git-town/v12/src/config/gitconfig"
-	"github.com/git-town/git-town/v12/src/git"
-	"github.com/git-town/git-town/v12/src/git/gitdomain"
-	"github.com/git-town/git-town/v12/src/gohacks"
-	"github.com/git-town/git-town/v12/src/gohacks/cache"
-	"github.com/git-town/git-town/v12/src/gohacks/stringslice"
-	"github.com/git-town/git-town/v12/src/messages"
-	"github.com/git-town/git-town/v12/src/subshell"
-	"github.com/git-town/git-town/v12/src/undo/undoconfig"
-	"github.com/git-town/git-town/v12/src/validate"
+	"github.com/git-town/git-town/v13/src/config"
+	"github.com/git-town/git-town/v13/src/config/configdomain"
+	"github.com/git-town/git-town/v13/src/config/configfile"
+	"github.com/git-town/git-town/v13/src/config/gitconfig"
+	"github.com/git-town/git-town/v13/src/git"
+	"github.com/git-town/git-town/v13/src/git/gitdomain"
+	"github.com/git-town/git-town/v13/src/gohacks"
+	"github.com/git-town/git-town/v13/src/gohacks/cache"
+	"github.com/git-town/git-town/v13/src/messages"
+	"github.com/git-town/git-town/v13/src/subshell"
+	"github.com/git-town/git-town/v13/src/undo/undoconfig"
+	"github.com/git-town/git-town/v13/src/validate"
 )
 
 func OpenRepo(args OpenRepoArgs) (*OpenRepoResult, error) {
@@ -58,7 +57,7 @@ func OpenRepo(args OpenRepoArgs) (*OpenRepoResult, error) {
 	if err != nil {
 		return nil, err
 	}
-	config, err := config.NewConfig(config.NewConfigArgs{
+	config, finalMessages, err := config.NewConfig(config.NewConfigArgs{
 		ConfigFile:   configFile,
 		DryRun:       args.DryRun,
 		GlobalConfig: globalConfig,
@@ -83,7 +82,7 @@ func OpenRepo(args OpenRepoArgs) (*OpenRepoResult, error) {
 			SetCachedCurrentBranch: backendCommands.CurrentBranchCache.Set,
 		},
 		CommandsCounter: &commandsCounter,
-		FinalMessages:   &stringslice.Collector{},
+		FinalMessages:   finalMessages,
 	}
 	rootDir := backendCommands.RootDirectory()
 	if args.ValidateGitRepo {
