@@ -368,7 +368,7 @@ func (self *BackendCommands) RepoStatus() (gitdomain.RepoStatus, error) {
 	}, nil
 }
 
-// RootDirectory provides the path of the rood directory of the current repository,
+// RootDirectory provides the path of the root directory of the current repository,
 // i.e. the directory that contains the ".git" folder.
 func (self *BackendCommands) RootDirectory() gitdomain.RepoRootDir {
 	output, err := self.Runner.QueryTrim("git", "rev-parse", "--show-toplevel")
@@ -426,17 +426,27 @@ func (self *BackendCommands) Version() (major int, minor int, err error) {
 }
 
 func (self *BackendCommands) currentBranchDuringRebase() (gitdomain.LocalBranchName, error) {
-	rootDir := self.RootDirectory()
-	rawContent, err := os.ReadFile(fmt.Sprintf("%s/.git/rebase-apply/head-name", rootDir))
+	output, err := self.Runner.QueryTrim("git", "branch", "--list")
 	if err != nil {
-		// Git 2.26 introduces a new rebase backend, see https://github.com/git/git/blob/master/Documentation/RelNotes/2.26.0.txt
-		rawContent, err = os.ReadFile(fmt.Sprintf("%s/.git/rebase-merge/head-name", rootDir))
-		if err != nil {
-			return gitdomain.EmptyLocalBranchName(), err
-		}
+		return gitdomain.EmptyLocalBranchName(), err
 	}
-	content := strings.TrimSpace(string(rawContent))
-	return gitdomain.NewLocalBranchName(strings.ReplaceAll(content, "refs/heads/", "")), nil
+	lines := stringslice.Lines(output)
+	linesWithStar := stringslice.LinesWithPrefix(lines, "* ")
+	if len(linesWithStar) == 0 {
+		return gitdomain.EmptyLocalBranchName(), err
+	}
+	if len(linesWithStar) > 1 {
+		panic("multiple lines with star found:\n " + output)
+	}
+	lineWithStar := linesWithStar[0]
+	return ParseActiveBranchDuringRebase(lineWithStar), nil
+}
+
+func ParseActiveBranchDuringRebase(lineWithStar string) gitdomain.LocalBranchName {
+	parts := strings.Split(lineWithStar, " ")
+	partsWithBranchName := parts[4:]
+	branchNameWithClosingParen := strings.Join(partsWithBranchName, " ")
+	return gitdomain.NewLocalBranchName(branchNameWithClosingParen[:len(branchNameWithClosingParen)-1])
 }
 
 // ParseVerboseBranchesOutput provides the branches in the given Git output as well as the name of the currently checked out branch.
