@@ -224,6 +224,31 @@ func TestBackendCommands(t *testing.T) {
 		must.False(t, runner.Backend.HasLocalBranch(gitdomain.NewLocalBranchName("b3")))
 	})
 
+	t.Run("parseActiveBranchDuringRebase", func(t *testing.T) {
+		t.Parallel()
+		t.Run("branch name is one word", func(t *testing.T) {
+			t.Parallel()
+			give := "* (no branch, rebasing feature)"
+			have := git.ParseActiveBranchDuringRebase(give)
+			want := gitdomain.NewLocalBranchName("feature")
+			must.Eq(t, want, have)
+		})
+		t.Run("branch name is two words", func(t *testing.T) {
+			t.Parallel()
+			give := "* (no branch, rebasing feature branch)"
+			have := git.ParseActiveBranchDuringRebase(give)
+			want := gitdomain.NewLocalBranchName("feature branch")
+			must.Eq(t, want, have)
+		})
+		t.Run("branch name is three words", func(t *testing.T) {
+			t.Parallel()
+			give := "* (no branch, rebasing the feature branch)"
+			have := git.ParseActiveBranchDuringRebase(give)
+			want := gitdomain.NewLocalBranchName("the feature branch")
+			must.Eq(t, want, have)
+		})
+	})
+
 	t.Run("RepoStatus", func(t *testing.T) {
 		t.Run("HasOpenChanges", func(t *testing.T) {
 			t.Parallel()
