@@ -571,6 +571,13 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		return nil
 	})
 
+	suite.Step(`^I resolve the conflict in "([^"]*)" in the other worktree$`, func(filename string) error {
+		content := "resolved content"
+		state.fixture.SecondWorktree.CreateFile(filename, content)
+		state.fixture.SecondWorktree.StageFiles(filename)
+		return nil
+	})
+
 	suite.Step(`^I (?:run|ran) "(.+)"$`, func(command string) error {
 		updateInitialSHAs(state)
 		state.runOutput, state.runExitCode = state.fixture.DevRepo.MustQueryStringCode(command)
@@ -602,6 +609,13 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		return nil
 	})
 
+	suite.Step(`^I run "([^"]*)" in the other worktree and enter "([^"]*)" for the commit message$`, func(cmd, message string) error {
+		state.fixture.SecondWorktree.MockCommitMessage(message)
+		state.runOutput, state.runExitCode = state.fixture.SecondWorktree.MustQueryStringCode(cmd)
+		state.fixture.SecondWorktree.Config.Reload()
+		return nil
+	})
+
 	suite.Step(`^I (?:run|ran) "([^"]+)" and enter into the dialogs?:$`, func(cmd string, input *messages.PickleStepArgument_PickleTable) error {
 		updateInitialSHAs(state)
 		env := os.Environ()
@@ -639,6 +653,12 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		return nil
 	})
 
+	suite.Step(`^I run "([^"]+)" in the other worktree$`, func(cmd string) error {
+		state.runOutput, state.runExitCode = state.fixture.SecondWorktree.MustQueryStringCode(cmd)
+		state.fixture.SecondWorktree.Config.Reload()
+		return nil
+	})
+
 	suite.Step(`^inspect the repo$`, func() error {
 		fmt.Printf("\nThe workspace is at %s\n", state.fixture.DevRepo.WorkingDir)
 		time.Sleep(1 * time.Hour)
@@ -1303,6 +1323,18 @@ func Steps(suite *godog.Suite, state *ScenarioState) {
 		return nil
 	})
 
+	suite.Step(`^the current branch in the other worktree is (?:now|still) "([^"]*)"$`, func(expected string) error {
+		state.fixture.SecondWorktree.CurrentBranchCache.Invalidate()
+		actual, err := state.fixture.SecondWorktree.CurrentBranch()
+		if err != nil {
+			return fmt.Errorf("cannot determine current branch of second worktree: %w", err)
+		}
+		if actual.String() != expected {
+			return fmt.Errorf("expected active branch %q but is %q", expected, actual)
+		}
+		return nil
+	})
+
 	suite.Step(`^the initial lineage exists$`, func() error {
 		have := state.fixture.DevRepo.LineageTable()
 		state.initialLineage.Sort()
